==> appslandia-common-3.2-sources.jar: com/appslandia/common/base/ConfigBase.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.base;

import java.sql.Date;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.appslandia.common.base.ToStringBuilder.Decision;
import com.appslandia.common.utils.DateUtils;
import com.appslandia.common.utils.ObjectUtils;
import com.appslandia.common.utils.SplitUtils;
import com.appslandia.common.utils.StringFormatUtils;
import com.appslandia.common.utils.StringUtils;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public abstract class ConfigBase implements Config {

	@Override
	public String getString(String key, String defaultValue) {
		String value = getString(key);
		return (value != null) ? value : defaultValue;
	}

	@Override
	public String getRequiredString(String key) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return value;
	}

	@Override
	public String[] getStringArray(String key) {
		String value = getString(key);
		if (value == null) {
			return StringUtils.EMPTY_ARRAY;
		}
		List<String> list = SplitUtils.splitByComma(value);
		return list.toArray(new String[list.size()]);
	}

	@Override
	public String getFormatted(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		Map<String, Object> m = ObjectUtils.cast(this.mapAccessor);
		return StringFormatUtils.format(value, m);
	}

	@Override
	public String getRequiredFormatted(String key) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		Map<String, Object> m = ObjectUtils.cast(this.mapAccessor);
		return StringFormatUtils.format(value, m);
	}

	@Override
	public String getFormatted(String key, Map<String, Object> parameters) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public String getRequiredFormatted(String key, Map<String, Object> parameters) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public String getFormatted(String key, Object... parameters) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public String getRequiredFormatted(String key, Object... parameters) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public boolean getBool(String key, boolean defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		if (isTrueValue(value)) {
			return true;
		}
		if (isFalseValue(value)) {
			return false;
		}
		return defaultValue;
	}

	@Override
	public boolean getRequiredBool(String key) throws NullPointerException, BoolFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		if (isTrueValue(value)) {
			return true;
		}
		if (isFalseValue(value)) {
			return false;
		}
		throw new BoolFormatException(value);
	}

	@Override
	public int getInt(String key, int defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Integer.parseInt(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public int getRequiredInt(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Integer.parseInt(value);
	}

	@Override
	public long getLong(String key, long defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Long.parseLong(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public long getRequiredLong(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Long.parseLong(value);
	}

	@Override
	public float getFloat(String key, float defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Float.parseFloat(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public float getRequiredFloat(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Float.parseFloat(value);
	}

	@Override
	public double getDouble(String key, double defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Double.parseDouble(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public double getRequiredDouble(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Double.parseDouble(value);
	}

	@Override
	public Date getDate(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		try {
			return DateUtils.iso8601Date(value);
		} catch (DateFormatException ex) {
			return null;
		}
	}

	@Override
	public java.sql.Date getRequiredDate(String key) throws NullPointerException, DateFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return DateUtils.iso8601Date(value);
	}

	@Override
	public Time getTime(String key) {
		String value = this.getString(key);
		if (value == null) {
			return null;
		}
		try {
			return DateUtils.iso8601Time(value);
		} catch (DateFormatException ex) {
			return null;
		}
	}

	@Override
	public Time getRequiredTime(String key) throws NullPointerException, DateFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return DateUtils.iso8601Time(value);
	}

	@Override
	public Timestamp getDateTime(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		try {
			return DateUtils.iso8601DateTime(value);
		} catch (DateFormatException ex) {
			return null;
		}
	}

	@Override
	public java.sql.Timestamp getRequiredDateTime(String key) throws NullPointerException, DateFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return DateUtils.iso8601DateTime(value);
	}

	protected abstract void putString(String key, String value);

	public ConfigBase put(String key, String value) {
		putString(key, StringUtils.trimToNull(value));
		return this;
	}

	public ConfigBase put(String key, boolean value) {
		putString(key, Boolean.toString(value));
		return this;
	}

	public ConfigBase put(String key, int value) {
		putString(key, Integer.toString(value));
		return this;
	}

	public ConfigBase put(String key, long value) {
		putString(key, Long.toString(value));
		return this;
	}

	public ConfigBase put(String key, float value) {
		putString(key, Float.toString(value));
		return this;
	}

	public ConfigBase put(String key, double value) {
		putString(key, Double.toString(value));
		return this;
	}

	public ConfigBase put(String key, Boolean value) {
		putString(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Integer value) {
		putString(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Long value) {
		putString(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Float value) {
		putString(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Double value) {
		putString(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, java.sql.Date value) {
		putString(key, (value != null) ? DateUtils.iso8601Date(value) : null);
		return this;
	}

	public ConfigBase put(String key, java.sql.Time value) {
		putString(key, (value != null) ? DateUtils.iso8601Time(value) : null);
		return this;
	}

	public ConfigBase put(String key, java.sql.Timestamp value) {
		putString(key, (value != null) ? DateUtils.iso8601DateTime(value) : null);
		return this;
	}

	@ToStringBuilder.EnableDecision(Decision.OBJECT_INFO)
	public Map<String, String> getMap() {
		return this.mapAccessor;
	}

	transient final Map<String, String> mapAccessor = new Map<String, String>() {

		@Override
		public String get(Object key) {
			return getString((String) key);
		}

		@Override
		public int size() {
			throw new UnsupportedOperationException();
		}

		@Override
		public boolean isEmpty() {
			throw new UnsupportedOperationException();
		}

		@Override
		public boolean containsKey(Object key) {
			throw new UnsupportedOperationException();
		}

		@Override
		public boolean containsValue(Object value) {
			throw new UnsupportedOperationException();
		}

		@Override
		public String put(String key, String value) {
			throw new UnsupportedOperationException();
		}

		@Override
		public String remove(Object key) {
			throw new UnsupportedOperationException();
		}

		@Override
		public void putAll(Map<? extends String, ? extends String> m) {
			throw new UnsupportedOperationException();
		}

		@Override
		public void clear() {
			throw new UnsupportedOperationException();
		}

		@Override
		public Set<String> keySet() {
			throw new UnsupportedOperationException();
		}

		@Override
		public Collection<String> values() {
			throw new UnsupportedOperationException();
		}

		@Override
		public Set<Entry<String, String>> entrySet() {
			throw new UnsupportedOperationException();
		}
	};

	private static boolean isTrueValue(String value) {
		return value.equalsIgnoreCase("true") || value.equalsIgnoreCase("yes");
	}

	private static boolean isFalseValue(String value) {
		return value.equalsIgnoreCase("false") || value.equalsIgnoreCase("no");
	}
}

==> appslandia-common-4.2-sources.jar: com/appslandia/common/base/ConfigBase.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.base;

import java.sql.Date;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.appslandia.common.utils.DateUtils;
import com.appslandia.common.utils.ObjectUtils;
import com.appslandia.common.utils.SplitUtils;
import com.appslandia.common.utils.StringFormatUtils;
import com.appslandia.common.utils.StringUtils;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public abstract class ConfigBase implements Config {

	protected final Map<String, String> props;

	public ConfigBase() {
		this.props = new HashMap<String, String>();
	}

	public ConfigBase(Map<String, String> newMap) {
		this.props = newMap;
	}

	@Override
	public String getString(String key, String defaultValue) {
		String value = getString(key);
		return (value != null) ? value : defaultValue;
	}

	@Override
	public String getRequiredString(String key) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return value;
	}

	@Override
	public String[] getStringArray(String key) {
		String value = getString(key);
		if (value == null) {
			return StringUtils.EMPTY_ARRAY;
		}
		List<String> list = SplitUtils.splitByComma(value);
		return list.toArray(new String[list.size()]);
	}

	@Override
	public String getFormatted(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		Map<String, Object> m = ObjectUtils.cast(this.mapAccessor);
		return StringFormatUtils.format(value, m);
	}

	@Override
	public String getRequiredFormatted(String key) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		Map<String, Object> m = ObjectUtils.cast(this.mapAccessor);
		return StringFormatUtils.format(value, m);
	}

	@Override
	public String getFormatted(String key, Map<String, Object> parameters) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public String getRequiredFormatted(String key, Map<String, Object> parameters) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public String getFormatted(String key, Object... parameters) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public String getRequiredFormatted(String key, Object... parameters) throws NullPointerException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return StringFormatUtils.format(value, parameters);
	}

	@Override
	public boolean getBool(String key, boolean defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		if (isTrueValue(value)) {
			return true;
		}
		if (isFalseValue(value)) {
			return false;
		}
		return defaultValue;
	}

	@Override
	public boolean getRequiredBool(String key) throws NullPointerException, BoolFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		if (isTrueValue(value)) {
			return true;
		}
		if (isFalseValue(value)) {
			return false;
		}
		throw new BoolFormatException(value);
	}

	@Override
	public int getInt(String key, int defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Integer.parseInt(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public int getRequiredInt(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Integer.parseInt(value);
	}

	@Override
	public long getLong(String key, long defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Long.parseLong(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public long getRequiredLong(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Long.parseLong(value);
	}

	@Override
	public float getFloat(String key, float defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Float.parseFloat(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public float getRequiredFloat(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Float.parseFloat(value);
	}

	@Override
	public double getDouble(String key, double defaultValue) {
		String value = getString(key);
		if (value == null) {
			return defaultValue;
		}
		try {
			return Double.parseDouble(value);
		} catch (NumberFormatException ex) {
			return defaultValue;
		}
	}

	@Override
	public double getRequiredDouble(String key) throws NullPointerException, NumberFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return Double.parseDouble(value);
	}

	@Override
	public Date getDate(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		try {
			return DateUtils.iso8601Date(value);
		} catch (DateFormatException ex) {
			return null;
		}
	}

	@Override
	public java.sql.Date getRequiredDate(String key) throws NullPointerException, DateFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return DateUtils.iso8601Date(value);
	}

	@Override
	public Time getTime(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		try {
			return DateUtils.iso8601Time(value);
		} catch (DateFormatException ex) {
			return null;
		}
	}

	@Override
	public Time getRequiredTime(String key) throws NullPointerException, DateFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return DateUtils.iso8601Time(value);
	}

	@Override
	public Timestamp getDateTime(String key) {
		String value = getString(key);
		if (value == null) {
			return null;
		}
		try {
			return DateUtils.iso8601DateTime(value);
		} catch (DateFormatException ex) {
			return null;
		}
	}

	@Override
	public java.sql.Timestamp getRequiredDateTime(String key) throws NullPointerException, DateFormatException {
		String value = getString(key);
		if (value == null) {
			throw new NullPointerException("key=" + key);
		}
		return DateUtils.iso8601DateTime(value);
	}

	@Override
	public String getString(String key) {
		return this.props.get(key);
	}

	public ConfigBase put(String key, String value) {
		this.props.put(key, StringUtils.trimToNull(value));
		return this;
	}

	public ConfigBase put(String key, boolean value) {
		this.props.put(key, Boolean.toString(value));
		return this;
	}

	public ConfigBase put(String key, int value) {
		this.props.put(key, Integer.toString(value));
		return this;
	}

	public ConfigBase put(String key, long value) {
		this.props.put(key, Long.toString(value));
		return this;
	}

	public ConfigBase put(String key, float value) {
		this.props.put(key, Float.toString(value));
		return this;
	}

	public ConfigBase put(String key, double value) {
		this.props.put(key, Double.toString(value));
		return this;
	}

	public ConfigBase put(String key, Boolean value) {
		this.props.put(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Integer value) {
		this.props.put(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Long value) {
		this.props.put(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Float value) {
		this.props.put(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, Double value) {
		this.props.put(key, (value != null) ? value.toString() : null);
		return this;
	}

	public ConfigBase put(String key, java.sql.Date value) {
		this.props.put(key, (value != null) ? DateUtils.iso8601Date(value) : null);
		return this;
	}

	public ConfigBase put(String key, java.sql.Time value) {
		this.props.put(key, (value != null) ? DateUtils.iso8601Time(value) : null);
		return this;
	}

	public ConfigBase put(String key, java.sql.Timestamp value) {
		this.props.put(key, (value != null) ? DateUtils.iso8601DateTime(value) : null);
		return this;
	}

	public Map<String, String> getMap() {
		return this.mapAccessor;
	}

	transient final Map<String, String> mapAccessor = new Map<String, String>() {

		@Override
		public String get(Object key) {
			return getString((String) key);
		}

		@Override
		public int size() {
			return props.size();
		}

		@Override
		public boolean isEmpty() {
			return props.isEmpty();
		}

		@Override
		public boolean containsKey(Object key) {
			return props.containsKey(key);
		}

		@Override
		public boolean containsValue(Object value) {
			throw new UnsupportedOperationException();
		}

		@Override
		public String put(String key, String value) {
			throw new UnsupportedOperationException();
		}

		@Override
		public String remove(Object key) {
			throw new UnsupportedOperationException();
		}

		@Override
		public void putAll(Map<? extends String, ? extends String> m) {
			throw new UnsupportedOperationException();
		}

		@Override
		public void clear() {
			throw new UnsupportedOperationException();
		}

		@Override
		public Set<String> keySet() {
			return Collections.unmodifiableSet(props.keySet());
		}

		@Override
		public Collection<String> values() {
			throw new UnsupportedOperationException();
		}

		@Override
		public Set<Entry<String, String>> entrySet() {
			throw new UnsupportedOperationException();
		}
	};

	private static boolean isTrueValue(String value) {
		return value.equalsIgnoreCase("true") || value.equalsIgnoreCase("yes");
	}

	private static boolean isFalseValue(String value) {
		return value.equalsIgnoreCase("false") || value.equalsIgnoreCase("no");
	}
}
